TileMerger
==========

.. currentmodule:: toasty.merge

.. autoclass:: TileMerger
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TileMerger.walk_callback

   .. rubric:: Methods Documentation

   .. automethod:: walk_callback
